# Getting Started

STACIE is a Python software library that can be used interactively in a Jupyter Notebook
or embedded non-interactively in larger computational workflows.

To get started:

- Install the `stacie` Python library (see [installation](installation.md)).
- Understand and accept the [open source licenses](licenses.md) we use.
- Get a bird's-eye view of [how to use](usage.md) STACIE.
- Know how to [cite](cite.md) STACIE when using it for your research.

A basic understanding of the [theory](../theory/index.md) is highly recommended
to ensure that you get the right result for the right reason.
The documentation contains several [worked examples](../examples/index.md)
that you can use as a starting point for your own research.

```{toctree}
:hidden:

installation.md
licenses.md
usage.md
cite.md
```
